pub struct AnyLuaString(pub Vec<u8>);Expand description
A byte string that may not be valid UTF-8, mirroring hlua::AnyLuaString.
Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl Clone for AnyLuaString
impl Clone for AnyLuaString
Sourcefn clone(&self) -> AnyLuaString
fn clone(&self) -> AnyLuaString
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnyLuaString
impl Debug for AnyLuaString
Sourceimpl Hash for AnyLuaString
impl Hash for AnyLuaString
Sourceimpl Ord for AnyLuaString
impl Ord for AnyLuaString
Sourcefn cmp(&self, other: &AnyLuaString) -> Ordering
fn cmp(&self, other: &AnyLuaString) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AnyLuaString
impl PartialEq for AnyLuaString
Sourcefn eq(&self, other: &AnyLuaString) -> bool
fn eq(&self, other: &AnyLuaString) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for AnyLuaString
impl PartialOrd for AnyLuaString
impl Eq for AnyLuaString
impl StructuralPartialEq for AnyLuaString