pub struct LuaFunction<L> { /* private fields */ }Expand description
A handle to a global Lua function, kept by name so it can be re-fetched and
called. Mirrors hlua::LuaFunction<L> (single type parameter).
Implementations
Sourceimpl<'a> LuaFunction<FnHandle<'a>>
impl<'a> LuaFunction<FnHandle<'a>>
Sourcepub fn call_with_args<V, A>(&mut self, args: A) -> Result<V, LuaError>where
A: PushArgs,
V: FromTop,
pub fn call_with_args<V, A>(&mut self, args: A) -> Result<V, LuaError>where
A: PushArgs,
V: FromTop,
Call the function with the given argument tuple and read one result.